@@ -12,11 +12,11 @@ PDF::Imposition - Perl module to manage the PDF imposition
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 
 =head1 SYNOPSIS
@@ -104,6 +104,22 @@ See L<PDF::Imposition::Schema4up>
 
 See L<PDF::Imposition::Schema1x4x2cutfoldbind>
 
+=item 1repeat2top
+
+See L<PDF::Imposition::Schema1repeat2top>
+
+=item 1repeat2side
+
+See L<PDF::Imposition::Schema1repeat2side>
+
+=item 1repeat4
+
+See L<PDF::Imposition::Schema1repeat4>
+
+=item ea4x4
+
+See L<PDF::Imposition::Schemaea4x4>
+
 =back
 
 =item cover
@@ -145,7 +161,7 @@ E.g.
 
 sub available_schemas {
     return qw/2up 2down 2side 2x4x2 1x4x2cutfoldbind
-              4up 1repeat2top 1repeat2side 1repeat4/;
+              4up 1repeat2top 1repeat2side 1repeat4 ea4x4/;
 }
 
 =head1 AUTHOR
